@@ -25,9 +25,12 @@
 #define PLATE_COLUMNS 5
 
 Control::Control()
- : showAll(false)
+ : showAll(new Lum::Model::Boolean(false))
 {
   SetBackground(new Lum::OS::EmptyFill()); // TODO: Is there a better way?
+
+  showAll->Disable();
+  Observe(showAll);
 }
 
 Control::~Control()
@@ -44,14 +47,22 @@ void Control::SetImage(Lum::Images::Image *image)
     plateState[i]=false;
   }
 
+  if (image!=NULL) {
+    showAll->Off();
+    showAll->Set(false);
+    showAll->Enable();
+    showAll->On();
+  }
+  else {
+    showAll->Disable();
+  }
+
   Redraw();
 }
 
-void Control::ToggleShowAll()
+Lum::Model::Boolean* Control::GetShowAll()
 {
-  showAll=!showAll;
-
-  Redraw();
+  return showAll;
 }
 
 void Control::CalcSize()
@@ -119,7 +130,7 @@ void Control::Draw(int x, int y, size_t w, size_t h)
   image->Resize(nw,nh);
   image->Draw(draw,(width-image->GetWidth())/2,(height-image->GetHeight())/2);
 
-  if (!showAll) {
+  if (!showAll->Get()) {
     for (size_t i=0; i<PLATE_ROWS*PLATE_COLUMNS; i++) {
       if (!plateState[i]) {
         draw->PushForeground(Lum::OS::display->GetColor(Lum::OS::Display::blackColor));
@@ -138,7 +149,7 @@ void Control::Draw(int x, int y, size_t w, size_t h)
 
 bool Control::HandleMouseEvent(const Lum::OS::MouseEvent& event)
 {
-  if (showAll || !image.Valid()) {
+  if (showAll->Get() || !image.Valid()) {
     return false;
   }
 
@@ -161,5 +172,12 @@ bool Control::HandleMouseEvent(const Lum::OS::MouseEvent& event)
   }
 
   return false;
- }
+}
+
+void Control::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
+{
+  if (model==showAll) {
+    Redraw();
+  }
+}
 
