@@ -24,26 +24,31 @@
 
 #include <Lum/Images/Image.h>
 
+#include <Lum/Model/Boolean.h>
+
 #include <Lum/Object.h>
 
 class Control : public Lum::Object
 {
 private:
-  Lum::Images::ImageRef image;
-  std::vector<bool>     plateState;
-  bool                  showAll;
+  Lum::Images::ImageRef  image;
+  std::vector<bool>      plateState;
+  Lum::Model::BooleanRef showAll;
 
 public:
   Control();
   ~Control();
 
   void SetImage(Lum::Images::Image *image);
-  void ToggleShowAll();
+
+  Lum::Model::Boolean* GetShowAll();
 
   void CalcSize();
   void Draw(int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
+
+  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 };
 
 #endif
